@@ -22,17 +22,17 @@ used the drive end data that are sampled at 48 kHz sampling frequency when load
 of 1 hp is applied on the shaft. Normal data collected with 1 hp load have also
 been used. There are a total of 10 classes. The classes are:
 
-  - C1 : Ball defect (0.007 inch, load: 1 hp)
-  - C2 : Ball defect (0.014 inch, load: 1 hp)
-  - C3 : Ball defect (0.021 inch, load: 1 hp)
-  - C4 : Inner race fault (0.007 inch, load: 1 hp)
-  - C5 : Inner race fault (0.014 inch, load: 1 hp)
-  - C6 : Inner race fault (0.021 inch, load: 1 hp)
-  - C7 : Normal (load: 1 hp)
-  - C8 : Outer race fault (0.007 inch, load: 1 hp, data collected from 6 O'clock
+  - C1: Ball defect (0.007 inch, load: 1 hp)
+  - C2: Ball defect (0.014 inch, load: 1 hp)
+  - C3: Ball defect (0.021 inch, load: 1 hp)
+  - C4: Inner race fault (0.007 inch, load: 1 hp)
+  - C5: Inner race fault (0.014 inch, load: 1 hp)
+  - C6: Inner race fault (0.021 inch, load: 1 hp)
+  - C7: Normal (load: 1 hp)
+  - C8: Outer race fault (0.007 inch, load: 1 hp, data collected from 6 O'clock
     position)
-  - C9 : Outer race fault (0.014 inch, load: 1 hp, 6 O'clock)
-  - C10 : Outer race fault (0.021 inch, load: 1 hp, 6 O'clock)
+  - C9: Outer race fault (0.014 inch, load: 1 hp, 6 O'clock)
+  - C10: Outer race fault (0.021 inch, load: 1 hp, 6 O'clock)
 
 From each category data are collected in segments of length 1024 and resized to
 a 2-D matrix of size (32 by 32). There is no overlap between segments. For each
@@ -156,9 +156,8 @@ def main():
         # Evaluate model accuracy
         if args.akida:
             model = convert(model)
-            prediction_labels = model.predict(test_data.astype(np.uint8))
-            accuracy = (np.sum(prediction_labels == np.argmax(test_labels, 1)) /
-                        prediction_labels.shape[0])
+            accuracy = model.evaluate(test_data.astype(np.uint8),
+                                      np.argmax(test_labels, 1))
             print(f'Akida accuracy: {accuracy}')
         else:
             evaluate_model(model,
