@@ -19,12 +19,12 @@ Convtiny model definition for CWRU classification.
 """
 
 from keras import Model
-from keras.layers import Input, Flatten, Softmax, Rescaling
+from keras.layers import Input, Softmax, Rescaling, Reshape
 from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model
 
-from ..layer_blocks import conv_block, dense_block
+from ..layer_blocks import conv_block, separable_conv_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/convtiny/'
 
@@ -57,10 +57,27 @@ def convtiny_cwru():
                    pooling='max',
                    pool_size=(2, 2))
 
-    x = Flatten(name='flatten')(x)
-    x = dense_block(x, units=64, name='dense_1', add_activation=True)
-    x = dense_block(x, units=96, name='dense_2', add_activation=True)
-    x = dense_block(x, units=10, name='predictions', add_activation=False)
+    x = separable_conv_block(x,
+                             filters=512,
+                             name='separable_1',
+                             kernel_size=(3, 3),
+                             padding='same',
+                             pooling='global_avg',
+                             use_bias=False,
+                             add_batchnorm=True,
+                             add_activation=True)
+
+    x = Reshape((1, 1, int(512)), name='reshape_1')(x)
+
+    x = separable_conv_block(x,
+                             filters=10,
+                             name='predictions',
+                             kernel_size=(3, 3),
+                             padding='same',
+                             use_bias=False,
+                             add_batchnorm=False,
+                             add_activation=False)
+    x = Reshape((10,), name='reshape_2')(x)
     x = Softmax(name='act_softmax')(x)
 
     return Model(img_input, x, name='convtiny_cwru_32_10')
@@ -76,7 +93,7 @@ def convtiny_cwru_pretrained():
 
     """
     model_name = 'convtiny_cwru_iq8_wq2_aq4.h5'
-    file_hash = '662e24c576f0c1b45f7bd25a9c855c282048ea88ca5e58fad67dad19c0f503c0'
+    file_hash = '15bc18ea85942185d90dbcd35300d86f8751bfd19ff175589d81e05dc2854d40'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
