@@ -30,12 +30,8 @@ class DVS_DataGenerator:
 
     Args:
         dataset (array): array of data stored in a dict.
-        inversion (bool, optional): flag to flip x/y coords.
-        packets_fixed_by (str, optional): value used to fix packet length, one
-            of 'duration' or (number of) 'events'. Defaults to 'duration'.
-        subpacket_length (int, optional): subpacket length (milliseconds if
-            packets_fixed_by='duration', event count if 'events'). Defaults to
-            100.
+        subpacket_length (int, optional): subpacket length (milliseconds).
+            Defaults to 100.
         subpackets_per_packet (int, optional): number of sub-packets (~ time
             bins) to concatenate to generate packets. Defaults to 1.
         camera_dims (tuple of ints, optional): dimensions of the raw data from
@@ -54,20 +50,14 @@ class DVS_DataGenerator:
 
     def __init__(self,
                  dataset,
-                 inversion=False,
-                 packets_fixed_by='duration',
                  subpacket_length=1000,
                  subpackets_per_packet=1,
                  camera_dims=(128, 128, 2),
                  include_polarity=True,
                  allow_duplicate_events=False,
                  downscale=1):
-        self.packets_fixed_by = packets_fixed_by
-        if packets_fixed_by.startswith('dur'):
-            # Convert milliseconds to microseconds
-            self.subpacket_length = subpacket_length * 1000
-        else:
-            self.subpacket_length = subpacket_length
+        # Convert milliseconds to microseconds
+        self.subpacket_length = subpacket_length * 1000
         self.subpackets_per_packet = subpackets_per_packet
         self.downscale = downscale
         if include_polarity:
@@ -79,21 +69,7 @@ class DVS_DataGenerator:
                             self.camera_dims[1] // downscale,
                             self.camera_dims[2] * subpackets_per_packet)
         self.allow_duplicate_events = allow_duplicate_events
-
         self.dataset = dataset
-        if not inversion:
-            # DVS gesture dataset is described and provided (and loaded) with
-            # classes indexed from 1, not 0.
-            # This modifier corrects for that offset
-            do_y_inversion = False
-            do_x_inversion = False
-            print('DVS dataset: coordinates not inverted')
-        else:
-            do_y_inversion = True
-            do_x_inversion = True
-            # Coordinates delivered by matlab reading are inverted,
-            # here we de-invert them
-            print('DVS dataset: pyfile coordinates inverted')
 
         self.subject_list = []
         trial_durations = []
@@ -103,21 +79,14 @@ class DVS_DataGenerator:
             if subj not in self.subject_list:
                 self.subject_list.append(subj)
             trial['label'] = int(trial['label']) - label_offset
-            if do_y_inversion:
-                # For camera dim of 128, calculation should be 127 - event
-                # coord
-                trial['events'][:, 1] = self.camera_dims[1] - trial[
-                    'events'][:, 1] - 1
-            if do_x_inversion:
-                trial['events'][:, 0] = self.camera_dims[0] - trial[
-                    'events'][:, 0] - 1
             trial_durations.append(trial['ev_times'][-1])
         self.trial_durations = trial_durations
 
     def get_random_samples(self,
                            class_list,
                            class_key=None,
-                           samples_per_trial=5):
+                           samples_per_trial=5,
+                           stop_time=None):
         """ Generates [samples_per_trial] samples from each subject/lighting
         condition/class.
 
@@ -127,6 +96,7 @@ class DVS_DataGenerator:
              None.
             samples_per_trial (int, optional): number of times that every sample
              have to be repeated. Defaults to 5.
+            stop_time (int, optional): samples ending point. Defaults to None.
 
         Returns:
             tuple: events and labels
@@ -137,22 +107,26 @@ class DVS_DataGenerator:
         outlabels = []
         sample_windows = []
         for _, trial in enumerate(self.dataset):
+            local_stop_time = stop_time
             if int(trial['label']) in class_list:
-                # Get latest start point (valid across all repeats)
-                num_events = trial['ev_times'].shape[0]
-                if self.packets_fixed_by.startswith('dur'):
-                    latest_start_time = trial['ev_times'][-1] - (
-                        self.subpacket_length * self.subpackets_per_packet)
-                    if latest_start_time < 0:
-                        print('ERROR: Sample durations requested is longer \
-                            than the available data for this trial')
-                        continue
-                    latest_start_point = np.searchsorted(np.squeeze(
-                        trial['ev_times']),
-                                                         latest_start_time,
-                                                         side='right') - 1
-                elif self.packets_fixed_by.startswith('ev'):
-                    latest_start_point = num_events - self.subpackets_per_packet * self.subpacket_length
+                if local_stop_time is None:
+                    local_stop_time = trial['ev_times'][-1]
+                elif local_stop_time > trial['ev_times'][-1]:
+                    print('ERROR: requested stop time later than the end of \
+                         the trial')
+                    print('Ending samples at ' + str(trial['ev_times'][-1]))
+                    local_stop_time = trial['ev_times'][-1]
+                latest_start_time = local_stop_time - \
+                    (self.subpacket_length * self.subpackets_per_packet)
+
+                if latest_start_time < 0:
+                    print('ERROR: Sample durations requested is longer \
+                        than the available data for this trial')
+                    continue
+                latest_start_point = np.searchsorted(np.squeeze(
+                    trial['ev_times']),
+                    latest_start_time,
+                    side='right') - 1
 
                 if latest_start_point < 0:
                     print("ERROR: Latest start point isn't valid")
@@ -168,15 +142,12 @@ class DVS_DataGenerator:
                         # Set packet end point relative to start point
                         # Convention here is EXCLUSIVE end_point, for clarity
                         # in python
-                        if self.packets_fixed_by.startswith('dur'):
-                            end_time = sample_start_time + \
-                                self.subpacket_length * (packet + 1)
-                            end_point = np.searchsorted(np.squeeze(
-                                trial['ev_times']),
-                                                        end_time,
-                                                        side='right')
-                        elif self.packets_fixed_by.startswith('ev'):
-                            end_point = start_point + self.subpacket_length
+                        end_time = sample_start_time + \
+                            self.subpacket_length * (packet + 1)
+                        end_point = np.searchsorted(np.squeeze(
+                            trial['ev_times']),
+                            end_time,
+                            side='right')
                         # Get the actual events
                         ev_array = np.copy(trial['events'][
                             np.squeeze(start_point):np.squeeze(end_point), :])
@@ -196,24 +167,13 @@ class DVS_DataGenerator:
                     outevents.append(sample_evs)
                     outlabels.append(class_key[class_list.index(
                         int(trial['label']))])
-                    if self.packets_fixed_by.startswith('dur'):
-                        sample_windows.append(end_point - sample_start_point)
-                    elif self.packets_fixed_by.startswith('ev'):
-                        sample_windows.append(trial['ev_times'][end_point - 1] -
-                                              sample_start_time)
+                    sample_windows.append(end_point - sample_start_point)
 
-        if self.packets_fixed_by.startswith('dur'):
-            mean_events = np.mean(np.array(sample_windows))
-            # mean_duration is in msecs
-            mean_duration = self.subpacket_length / 1000 * self.subpackets_per_packet
-            # mean_ev_rate stores events per second
-            mean_ev_rate = mean_events / mean_duration * 1000
-        elif self.packets_fixed_by.startswith('ev'):
-            mean_events = self.subpacket_length * self.subpackets_per_packet
-            # ev_rate stores events per msecs
-            ev_rates = mean_events / np.array(sample_windows) * 1000
-            # mean_ev_rate stores events per second
-            mean_ev_rate = np.mean(ev_rates) * 1000
+        mean_events = np.mean(np.array(sample_windows))
+        # mean_duration is in msecs
+        mean_duration = self.subpacket_length / 1000 * self.subpackets_per_packet
+        # mean_ev_rate stores events per second
+        mean_ev_rate = mean_events / mean_duration * 1000
         print('DVS event rate: ' + str(np.round(mean_ev_rate)) + ' events/sec')
 
         outlabels = np.array(outlabels)
@@ -224,7 +184,8 @@ class DVS_DataGenerator:
                               class_label,
                               class_key=None,
                               start_time=0,
-                              stop_time=None):
+                              stop_time=None,
+                              overlapping_samples=True):
         """ Generates series of temporally contiguous samples from a single
         subject+class.
 
@@ -234,6 +195,8 @@ class DVS_DataGenerator:
             class_key (int, optional): key of the class. Defaults to None.
             start_time (int, optional): samples starting point. Defaults to 0.
             stop_time (int, optional): samples ending point. Defaults to None.
+            overlapping_samples(bool, optional): samples overlapping. Defaults
+                to True.
 
         Returns:
             tuple: events, labels, plot events
@@ -248,8 +211,6 @@ class DVS_DataGenerator:
             local_stop_time = stop_time
             if (int(trial['label']) == class_label) and (int(trial['subject'])
                                                          == subj):
-                # Get latest start point (valid across all repeats)
-                num_events = trial['ev_times'].shape[0]
                 if local_stop_time is None:
                     local_stop_time = trial['ev_times'][-1]
                 elif local_stop_time > trial['ev_times'][-1]:
@@ -257,34 +218,24 @@ class DVS_DataGenerator:
                          the trial')
                     print('Ending samples at ' + str(trial['ev_times'][-1]))
                     local_stop_time = trial['ev_times'][-1]
-                if self.packets_fixed_by.startswith('dur'):
-                    latest_start_time = local_stop_time - \
-                        (self.subpacket_length * self.subpackets_per_packet)
-                    if latest_start_time < 0:
-                        print('ERROR: Sample durations requested is longer \
-                            than the available data for this trial (or stop \
-                            time is set too early)')
-                        continue
-                    latest_start_point = np.searchsorted(np.squeeze(
-                        trial['ev_times']),
-                                                         latest_start_time,
-                                                         side='right') - 1
-                elif self.packets_fixed_by.startswith('ev'):
-                    if local_stop_time < trial['ev_times'][-1]:
-                        stop_point = np.searchsorted(np.squeeze(
-                            trial['ev_times']),
-                                                     local_stop_time,
-                                                     side='right') - 1
-                    else:
-                        stop_point = num_events
-                    latest_start_point = stop_point - self.subpackets_per_packet * self.subpacket_length
+                latest_start_time = local_stop_time - \
+                    (self.subpacket_length * self.subpackets_per_packet)
+                if latest_start_time < 0:
+                    print('ERROR: Sample durations requested is longer \
+                        than the available data for this trial (or stop \
+                        time is set too early)')
+                    continue
+                latest_start_point = np.searchsorted(np.squeeze(
+                    trial['ev_times']),
+                    latest_start_time,
+                    side='right') - 1
 
                 # Build samples from multiple packets
                 if start_time > 0:
                     sample_start_point = np.searchsorted(np.squeeze(
                         trial['ev_times']),
-                                                         start_time,
-                                                         side='left')
+                        start_time,
+                        side='left')
                 else:
                     sample_start_point = 0
                 sample_start_time = start_time
@@ -296,15 +247,12 @@ class DVS_DataGenerator:
                         # Set packet end point relative to start point
                         # Convention here is EXCLUSIVE end_point, for clarity
                         # in python
-                        if self.packets_fixed_by.startswith('dur'):
-                            end_time = sample_start_time + \
-                                self.subpacket_length * (packet + 1)
-                            end_point = np.searchsorted(np.squeeze(
-                                trial['ev_times']),
-                                                        end_time,
-                                                        side='right')
-                        elif self.packets_fixed_by.startswith('ev'):
-                            end_point = start_point + self.subpacket_length
+                        end_time = sample_start_time + \
+                            self.subpacket_length * (packet + 1)
+                        end_point = np.searchsorted(np.squeeze(
+                            trial['ev_times']),
+                            end_time,
+                            side='right')
 
                         # Get the actual events
                         plot_array = np.copy(trial['events'][
@@ -326,17 +274,15 @@ class DVS_DataGenerator:
                     outevents.append(sample_evs)
                     outlabels.append(class_key)
                     plotevents.append(plot_evs)
-                    if self.packets_fixed_by.startswith('dur'):
-                        sample_windows.append(end_point - sample_start_point)
+                    sample_windows.append(end_point - sample_start_point)
+                    if overlapping_samples:
                         sample_start_time += self.subpacket_length
-                        sample_start_point = np.searchsorted(np.squeeze(
-                            trial['ev_times']),
-                                                             sample_start_time,
-                                                             side='right')
-                    elif self.packets_fixed_by.startswith('ev'):
-                        sample_windows.append(trial['ev_times'][end_point - 1] -
-                                              sample_start_time)
-                        sample_start_point += self.subpacket_length
+                    else:
+                        sample_start_time += self.subpacket_length * self.subpackets_per_packet
+                    sample_start_point = np.searchsorted(np.squeeze(
+                        trial['ev_times']),
+                        sample_start_time,
+                        side='right')
         outlabels = np.array(outlabels)
         return outevents, outlabels, plotevents
 
@@ -378,7 +324,13 @@ class DVS_DataGenerator:
         for sample in samples_events:
             sample_mat = self.events2matrix(sample)
             outmat.append(sample_mat)
-        return np.array(outmat)
+
+        out_arr = np.array(outmat)
+
+        if self.allow_duplicate_events:
+            out_arr = np.clip(out_arr, 0, 15)
+
+        return out_arr
 
     def augment_data(self,
                      samples_events,
