@@ -21,9 +21,9 @@ constraint.
 
 import warnings
 
-from tensorflow.keras.models import clone_model
-from tensorflow.keras.utils import custom_object_scope
-from tensorflow.keras.layers import BatchNormalization
+from keras.models import clone_model
+from keras.utils.generic_utils import custom_object_scope
+from keras.layers import BatchNormalization
 
 from cnn2snn.min_value_constraint import MinValueConstraint
 
@@ -34,8 +34,8 @@ def add_gamma_constraint(model):
 
     This is typically used to help having a model that will be Akida compatible
     after conversion. In some cases, the mapping on hardware will fail because
-    of huge values for `threshold_fire` or `threshold_fire_step` with a message
-    indicating that a value cannot fit in a 20 bit signed or unsigned integer.
+    of huge values for `threshold` or `act_step` with a message indicating that
+    a value cannot fit in a 20 bit signed or unsigned integer.
     In such a case, this helper can be called to apply a constraint that can fix
     the issue.
 
@@ -46,11 +46,11 @@ def add_gamma_constraint(model):
     trained yet.
 
     Args:
-        model (tf.keras.Model): the model for which gamma constraints will be
+        model (keras.Model): the model for which gamma constraints will be
             added.
 
     Returns:
-        tf.keras.Model: the same model with BatchNormalisation layers updated.
+        keras.Model: the same model with BatchNormalisation layers updated.
     """
 
     def apply_gamma_constraint(layer):
