@@ -67,7 +67,7 @@ def _obtain_input_shape(input_shape, default_size, min_size, include_top):
                 raise ValueError(
                     '`input_shape` must be a tuple of three integers.')
             if ((input_shape[0] is not None and input_shape[0] < min_size) or
-                (input_shape[1] is not None and input_shape[1] < min_size)):
+                    (input_shape[1] is not None and input_shape[1] < min_size)):
                 raise ValueError('Input size must be at least ' +
                                  str(min_size) + 'x' + str(min_size) +
                                  '; got `input_shape=' + str(input_shape) + '`')
@@ -350,7 +350,7 @@ def akidanet_imagenet(input_shape=None,
                   (alpha, input_shape[0], classes))
 
     if ((weight_quantization != 0) or (activ_quantization != 0) or
-        (input_weight_quantization != 0)):
+            (input_weight_quantization != 0)):
         return quantize(model, weight_quantization, activ_quantization,
                         input_weight_quantization)
     return model
@@ -421,7 +421,7 @@ def akidanet_imagenette_pretrained(alpha=1.0):
     """
     if alpha == 1.0:
         model_name = 'akidanet_imagenette_224_iq8_wq4_aq4.h5'
-        file_hash = 'c99e1249802bb5b6348ca6746416cc9e903ef5c43f52ea734caef15916494904'
+        file_hash = '7c29aa9362685643b782868c7f73a5f0f1ed64c38896d894b90d78fb83fecfa6'
     elif alpha == 0.5:
         model_name = 'akidanet_imagenette_224_alpha_50_iq8_wq4_aq4.h5'
         file_hash = '6729a203605f527fd0cff76d76275ef74be2f467cd5e3abc9df3d7df54c1c2c9'
@@ -568,3 +568,41 @@ def akidanet_plantvillage_pretrained():
                           file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
+
+
+def akidanet_cifar10_pretrained():
+    """
+    Helper method to retrieve an `akidanet_imagenet` model that was trained on
+    CIFAR-10 dataset. Since CIFAR-10 images have a 32x32 size, they need to be
+    resized to match akidanet input layer. This can be done by calling the
+    'resize_image' function available under akida_models.cifar10.preprocessing.
+
+    Returns:
+        keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'akidanet_cifar10_iq8_wq4_aq4.h5'
+    file_hash = 'c645cf132c9641e3d0b3611baf7c1cab143aa29d6289a976bd9064e533a6afa0'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
+
+
+def akidanet_vww_pretrained():
+    """
+    Helper method to retrieve an `akidanet_imagenet` model that was trained on
+    VWW dataset.
+
+    Returns:
+        keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'akidanet_vww_iq8_wq4_aq4.h5'
+    file_hash = '3c1f842cae0cb65abcda1197e4451c6ed24eb0f7dbc74be5d96441e478b7c1a8'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
