@@ -39,8 +39,7 @@ def get_data():
     # Load pre-processed dataset
     fname = get_file(
         fname='kws_preprocessed_all_words_except_backward_follow_forward.pkl',
-        origin=
-        'http://data.brainchip.com/dataset-mirror/kws/kws_preprocessed_all_words_except_backward_follow_forward.pkl',
+        origin='http://data.brainchip.com/dataset-mirror/kws/kws_preprocessed_all_words_except_backward_follow_forward.pkl',
         cache_subdir=os.path.join('datasets', 'kws'))
 
     print('Loading pre-processed dataset...')
@@ -132,8 +131,7 @@ def main():
         # Evaluate model accuracy
         if args.akida:
             model_ak = convert(model)
-            preds = model_ak.predict(x_val.astype('uint8'))
-            accuracy = (y_val == preds).mean()
+            accuracy = model_ak.evaluate(x_val.astype('uint8'), y_val)
             print(f"Accuracy: {accuracy}")
         else:
             evaluate_model(model, x_val, y=to_categorical(y_val))
