@@ -37,7 +37,7 @@ def get_data():
     Returns:
         tuple: train data, train labels, test data and test labels
     """
-    #The data, shuffled and split between train and test sets
+    # The data, shuffled and split between train and test sets
     (x_train, y_train), (x_test, y_test) = mnist.load_data()
 
     # Normalize data
@@ -138,9 +138,8 @@ def main():
         # Evaluate model accuracy
         if args.akida:
             model_ak = convert(model)
-            preds = model_ak.predict(x_test.astype('uint8'))
-            accuracy = (y_test == preds).mean()
-            print(f"Accuracy : {accuracy}")
+            accuracy = model_ak.evaluate(x_test.astype('uint8'), y_test)
+            print(f"Accuracy: {accuracy}")
         else:
             evaluate_model(model, x_test, y=y_test)
 
