@@ -103,7 +103,7 @@ def evaluate_model(model, test_dataset):
         for batch, _ in test_dataset:
             # Rescale inputs to Akida
             pots = (batch.numpy() * 127 + 127).astype('uint8')
-            pots_batch = model.evaluate(pots)
+            pots_batch = model.predict(pots)
             pots_akida = np.concatenate((pots_akida, pots_batch.squeeze()))
 
         preds = np.squeeze(np.argmax(pots_akida, 1))
