@@ -99,7 +99,7 @@ def main():
         # Evaluate model accuracy
         if args.akida:
             model_ak = convert(model)
-            y = model_ak.evaluate(x_test)
+            y = model_ak.predict(x_test.astype(np.uint8))
             mae = np.sum(np.abs(y_test.squeeze() - y.squeeze())) / len(y_test)
             print("Validation accuracy: {0:.4f}".format(mae))
         else:
